# Manifestoo Core

[![Github-CI][github-ci]][github-link]
[![Coverage Status][codecov-badge]][codecov-link]
[![PyPI][pypi-badge]][pypi-link]

<!--- shortdesc-begin -->

A library to reason about [Odoo](https://odoo.com) addons manifests.

<!--- shortdesc-end -->

## Installation

<!--- install-begin -->

```console
pip install manifestoo-core
```

<!--- install-end -->

## Features

<!--- features-begin -->

/!\ For now the API is not considered stable and is not documented. It is reserved for
private use by `manifestoo`.

<!--- features-end -->

## Quick start

<!--- quickstart-begin -->

TODO

<!--- quickstart-end -->


[github-ci]: https://github.com/sbidoul/manifestoo-core/actions/workflows/ci.yml/badge.svg
[github-link]: https://github.com/sbidoul/manifestoo-core
[codecov-badge]: https://codecov.io/gh/sbidoul/manifestoo-core/branch/master/graph/badge.svg
[codecov-link]: https://codecov.io/gh/sbidoul/manifestoo-core
[pypi-badge]: https://img.shields.io/pypi/v/manifestoo-core.svg
[pypi-link]: https://pypi.org/project/manifestoo-core
